@@ -1,8 +1,10 @@
 import argparse  # pragma: no cover
+import logging
+import os.path
+
+import yaml
 
 from . import checkatlas  # pragma: no cover
-import logging
-import yaml
 from . import atlas
 
 
@@ -17,7 +19,6 @@ def main() -> None:  # pragma: no cover
     Search fo atlases is managed here
     Then checkatlas is ran with the list of atlases found
     """
-
     # Set up logging
     logger = logging.getLogger("checkatlas")
     logging.basicConfig(format="|--- %(levelname)-8s %(message)s")
@@ -39,7 +40,7 @@ def main() -> None:  # pragma: no cover
     parser.add_argument(
         "path",
         type=str,
-        help="Your folder containing Scanpy, CellRanger and Seurat atlasesv",
+        help="Required argument: Your folder containing Scanpy, CellRanger and Seurat atlasesv",
         default=".",
     )
     parser.add_argument(
@@ -83,6 +84,13 @@ def main() -> None:  # pragma: no cover
         action="store_true",
         help="Print out all debug messages.",
     )
+    parser.add_argument(
+        "-v",
+        "--version",
+        action="version",
+        version=f"Checkatlas {get_version()}",
+        help="Display checkatlas version.",
+    )
 
     # Pipeline arguments
     pipeline_options = parser.add_argument_group("Manage checkatlas pipeline")
@@ -148,7 +156,7 @@ def main() -> None:  # pragma: no cover
         "--metric_cluster",
         nargs="+",
         type=str,
-        default=["silhouette", "davies_boudin"],
+        default=["silhouette", "davies_bouldin"],
         help="List of clustering metrics to calculate."
         "To get a complete list of metrics, look here:"
         "https://github.com/becavin-lab/checkatlas/"
@@ -204,10 +212,26 @@ def main() -> None:  # pragma: no cover
     # Save all arguments to yaml (only run it when
     # generating example file config.yaml
     # save_arguments(args, 'config/default_config.yaml')
-
+    # test_r()
     checkatlas.run(args)
 
 
+def test_r():
+    seurat_path = "/Users/christophebecavin/Documents/testatlas/PAH_675093.rds"
+    import rpy2
+
+    print(seurat_path)
+    import rpy2.robjects as robjects
+
+    from . import atlas_seurat
+
+    # atlas_seurat.install_library()
+    rcode = f'readRDS("{seurat_path}")'
+    print(rcode)
+    seurat = robjects.r(rcode)
+    print(seurat)
+
+
 def load_arguments(args, yaml_name):
     """
     Load all args from a yaml file.
@@ -242,5 +266,16 @@ def save_arguments(args, yaml_name):
         yaml.dump(args.__dict__, config_file)
 
 
+def get_version():
+    """
+    Get version of checkatlas from checkatlas/VERSION file
+    :return: checkatlas version
+    """
+    script_path = os.path.dirname(os.path.realpath(__file__))
+    version_file = os.path.join(script_path, "VERSION")
+    with open(version_file, "r") as version:
+        return version.readlines()[0].strip()
+
+
 if __name__ == "__main__":  # pragma: no cover
     main()
